# -*- coding: utf-8 -*-
import uuid
#import requests
from .yige_requests import (
    #VoiceRequest,
    TextRequest,
    UserEntitiesRequest,
    #events
)

DEFAULT_VERSION = '20170115' #python client version

class Yige(object):
    """
    Main endpoint for using yige.ai
    Provides request.

    Basic Usage::
            >>> ...
            >>> import yige
            >>> ai = yige.Yige(<CLIENT_ACCESS_TOKEN>)
            >>> text_request = ai.text_request()
            >>> ...
        :param client_access_token: client access token provided by http://yige.ai/
        :type client_access_token: str or unicde
    """
    # property 允许设置前校验

    @property
    def client_access_token(self):
        """
            Client access token provided by https://yige.ai/
            :rtype: str or unicode
        """

        return self._client_access_token

    @client_access_token.setter
    def client_access_token(self, client_access_token):
        """
            :type client_access_token: str or unicode

            todo: use env var? os.environ.get("yige_client_access_token")
        """

        self._client_access_token = client_access_token

    @property
    def session_id(self):
        """
            session_id user for unique identifier of current application user.
            And it provide different contexts and entities for different users.
            Default it generated like uuid for every object of `Yige` class.
            :rtype: str or unicode
        """

        return self._session_id



    @session_id.setter
    def session_id(self, session_id):
        """
            :type session_id: str or unicode
        """

        self._session_id = session_id

    def __init__(self, client_access_token, session_id=None):
        super(Yige, self).__init__()
        self._client_access_token = client_access_token

        self._base_url = 'http://api.yige.ai'
        self._version = DEFAULT_VERSION

        if session_id is None:
            self._session_id = uuid.uuid4().hex
        else:
            self._session_id = session_id

    def text_request(self):
        """
            Fields of request default filled from `Yige` parameters
            (session_id, version,client_access_token).
            Returns `TextRequest` object.
            :rtype TextRequest:
        """

        request = TextRequest(
            self.client_access_token,
            self._base_url,
            self._version,
            self.session_id
        )

        return request
    
    # 增删，自定义实体
    def user_entities_request(self, user_entities=None):
        """
            Construct a `UserEntitiesRequest`, prepare it.
            Returns `UserEntitiesRequest` object.
            :rtype UserEntitiesRequest:
        """

        if user_entities is None:
            user_entities = []

        request = UserEntitiesRequest(
            self.client_access_token, # 这个是dev token
            self._base_url,
            self._version
            #user_entities
        )

        return request


# -*- coding: utf-8 -*-

"""
yige
~~~~~~~~~~~~~~~~
This module provides a yige.ai classes to manage requests.
"""

__author__ = """wenjiewu"""
__email__ = 'wuwenjie718@gmail.com'
__version__ = '0.1.0'
__contributors__ = []
__license__ = "MIT"
from .yige import Yige
# 使用相对路径引用内部模块，对外暴露
# https://github.com/api-ai/api-ai-python/blob/master/apiai/__init__.py

# 对外暴露
__all__ = ['Yige']



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    "requests",
    # TODO: put package requirements here
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='yige',
    version='0.1.0',
    description="Python library for yige.ai",
    long_description=readme + '\n\n' + history,
    author="wenjiewu",
    author_email='wuwenjie718@gmail.com',
    url='https://github.com/wwj718/yige',
    packages=[
        'yige',
    ],
    package_dir={'yige':
                 'yige'},
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords='yige',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)



# encoding: utf-8
from __future__ import unicode_literals
import os
import requests


class TextRequest(object):
    @property
    def query(self):
        """
            Query parameter, can be string or array of strings.
            Default equal None, nut your should fill this field before send
            request.
            :rtype: str or unicode
        """
        return self._query

    @query.setter
    def query(self, query):
        self._query = query

    def __init__(self, client_access_token, base_url, version,
                 session_id):
        # query是直接请求还是，设置，重复利用
        # 延迟触发 getresponse,使用类来做，初始化好，然后query随时调整
        self.query = None

        path = "/v1/query"
        self.query_url = base_url + path
        self.payload = {}
        self.payload["token"] = client_access_token  #客户端toke
        self.payload["session_id"] = session_id

    def getresponse(self):
        # 允许设置query
        #query
        #if self._query:
        # 请输入query
        self.payload["query"] = self._query
        r = requests.post(self.query_url, data=self.payload)
        return r  #不做任何处理，直接返回

        # 如果解析出意图，如果没有解析出意图 置信度
        '''
        if r.status_code == 200:
            r_json = r.json()
            #answer = r_json["answer"]
            return r_json
            #print(r_json[])
        else:
            return "something error"
        '''


class UserEntitiesRequest(object):
    @property
    def user_entities(self):
        "user_entities parameter for specification of same user entities."
        return self._user_entities

    @user_entities.setter
    def user_entities(self, user_entities):
        self._user_entities = user_entities

    def __init__(self, client_access_token, base_url, version):#,user_entities):
        self._user_entities = None
        #self.client_access_token = client_access_token #os.environ.get("YIGE_DEV_TOKEN")  # export YIGE_DEV_TOKEN=xxx
        self.headers = {
            "Authorization": "{}".format(client_access_token),  # 开发者token
            "Content-Type": "application/json; charset=utf-8"
            #"User-Agent": "PythonClient/0.1 by python client"
        }
        path = "/v1/entities"  
        self.entity_url  = base_url + path
        #self.url = "http://httpbin.org/post"  # test 正常
    
    def getresponse(self):#正式提交
            response = requests.post(self.entity_url,
                                     json=self.user_entities,
                                     headers=self.headers,
                                     verify=False)
            return response
            #r_json = response.json()
            #print(r_json)
            #print(response)
            #def get
